@@ -160,6 +160,9 @@ connect_now_show_settings_dialog(GtkWidget* widget, gpointer data)
 
   // Display name
   display_name_entry = hildon_entry_new(HILDON_SIZE_FINGER_HEIGHT | HILDON_SIZE_AUTO_WIDTH);
+  if(desktop_plugin->connection_name!=NULL)
+    gtk_entry_set_text(GTK_ENTRY(display_name_entry),
+		       desktop_plugin->connection_name);
 
   display_name_check_button = hildon_check_button_new(HILDON_SIZE_AUTO);
   hildon_check_button_set_active(HILDON_CHECK_BUTTON(display_name_check_button),
@@ -470,11 +473,22 @@ connect_now_realize(GtkWidget* widget)
   GdkScreen *screen = gtk_widget_get_screen(widget);
   gtk_widget_set_colormap(widget, gdk_screen_get_rgba_colormap(screen));
   gtk_widget_set_app_paintable(widget, TRUE);
-  CONNECT_NOW_HOME_PLUGIN(widget)->iD = hd_home_plugin_item_get_applet_id (HD_HOME_PLUGIN_ITEM (widget));
-  read_settings(CONNECT_NOW_HOME_PLUGIN(widget));
+  ConnectNowHomePlugin *desktop_plugin = CONNECT_NOW_HOME_PLUGIN(widget);
+  desktop_plugin->iD = hd_home_plugin_item_get_applet_id (HD_HOME_PLUGIN_ITEM (widget));
+  read_settings(desktop_plugin);
+  if(desktop_plugin->connectedImage == NULL)
+  {
+    desktop_plugin->connectedImageName = g_strdup(GENERAL_CONNECTED);
+    desktop_plugin->connectedImage = load_image(desktop_plugin->connectedImageName);
+  }
+  if(desktop_plugin->disconnectedImage == NULL)
+  {
+    desktop_plugin->disconnectedImageName = g_strdup(GENERAL_DISCONNECTED);
+    desktop_plugin->disconnectedImage = load_image(desktop_plugin->disconnectedImageName);
+  }
   gtk_window_resize(GTK_WINDOW(widget),
-		    CONNECT_NOW_HOME_PLUGIN(widget)->widget_size,
-		    CONNECT_NOW_HOME_PLUGIN(widget)->widget_size);
+		    desktop_plugin->widget_size,
+		    desktop_plugin->widget_size);
 
   GTK_WIDGET_CLASS(connect_now_home_plugin_parent_class)->realize(widget);
 }
